@@ -52,7 +52,7 @@ class Easyocrpipleline:
             path (string): file path
             reader (object): easy ocr object
         """
-        reader = easyocr.Reader(['hi', 'en'])
+        reader = easyocr.Reader(['en'])
         result = reader.readtext(path,width_ths=0)
         self.create_json(result, path)
 
@@ -65,7 +65,7 @@ class Easyocrpipleline:
             reader (object): easy ocr object
         """
         img = Image.open(path)  
-        reader = easyocr.Reader(['hi', 'en'])
+        reader = easyocr.Reader(['en'])
         tif_file_name=path.split('.tif')[0]
         for i in range(img.n_frames):
             print(img.n_frames)
